@@ -169,7 +169,7 @@ def get_node(repopath, node, snapshot, ref, connector):
         "source": parts[0],
         "path": base_path + node['path'],
         "timestamp": int(time.time() * 1000),
-        "queryuser": "",
+        "queryuser": get_field_value(snapshot, 'testUser'),
         "checksum": hashlib.md5("{}".encode('utf-8')).hexdigest(),
         "node": node,
         "snapshotId": node['snapshotId'],
@@ -207,7 +207,7 @@ def get_all_nodes(repopath, node, snapshot, ref, connector):
         "source": parts[0],
         "path": '',
         "timestamp": int(time.time() * 1000),
-        "queryuser": "",
+        "queryuser": get_field_value(snapshot, 'testUser'),
         "checksum": hashlib.md5("{}".encode('utf-8')).hexdigest(),
         "node": node,
         "snapshotId": None,
